/*

  NRF24L01 Module (Receiver)

  Parts required:
  - Arduino Board
  - Breadboard
  - NRF24L01 
  - LED
  - 330 Ohm Resistor

  Libraries required:
  - RF24 version 1.3.4 or later

  Programming by : René Rasmussen
  Website : www.it-teknolog.dk
  Contact : renerasmussen@it-teknolog.dk
  Date : 14 May 2020
  Version : v1.0

*/

#include <SPI.h>                        // include SPI library
#include <nRF24L01.h>                   // include nRF24L01 library
#include <RF24.h>                       // include RF24 library

RF24 radio(7, 8);                       // set RF24 Chip enable to port 7 and SPI chip select
const byte address[6] = "00001";        // set variable address as byte and store 00001

boolean state = 0;                      // set state variable to 0
int led_pin = 6;                        // set led_pin to port 6

void setup() {
  pinMode(led_pin, OUTPUT);             // set led_pin to OUTPUT
  radio.begin();                        // start radio communication via NRF24L01
  radio.openReadingPipe(0, address);    // set the address at which we will receive the data
  radio.setPALevel(RF24_PA_MIN);        // set this as minimum or maximum depending on the distance between the transmitter and receiver.
  radio.startListening();               // start NRF24L01 for listening and start the module as receiver
}

void loop()
{
  radio.read(&state, sizeof(state));    // read value from NRF24L01 input state
  if (state == HIGH)                    // if state = HIGH
  {
    digitalWrite(led_pin, HIGH);        // set led_pin to HIGH
  }
  else
  {
    digitalWrite(led_pin, LOW);         // set led_pin to LOW
  }
  delay(1000);                          // wait 1000ms
}
